@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -36,14 +36,12 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
 #include <packagekit-glib2/packagekit.h>
-#ifdef GPK_BUILD_GUDEV
+#ifdef HAVE_GUDEV
 #include <gudev/gudev.h>
 #endif
 
-#include "egg-debug.h"
 #include "egg-string.h"
 #include "egg-console-kit.h"
 
@@ -65,7 +63,7 @@ static void     gpk_firmware_finalize	(GObject	  *object);
 struct GpkFirmwarePrivate
 {
 	EggConsoleKit		*consolekit;
-	GConfClient		*gconf_client;
+	GSettings		*settings;
 	GFileMonitor		*monitor;
 	GPtrArray		*array_requested;
 	PkTask			*task;
@@ -110,7 +108,7 @@ static GpkFirmwareRequest *
 gpk_firmware_request_new (const gchar *filename, const gchar *sysfs_path)
 {
 	GpkFirmwareRequest *req;
-#ifdef GPK_BUILD_GUDEV
+#ifdef HAVE_GUDEV
 	GUdevDevice *device;
 	GUdevClient *client;
 	const gchar *subsystem;
@@ -123,7 +121,7 @@ gpk_firmware_request_new (const gchar *filename, const gchar *sysfs_path)
 	req->filename = g_strdup (filename);
 	req->sysfs_path = g_strdup (sysfs_path);
 	req->subsystem = GPK_FIRMWARE_SUBSYSTEM_UNKNOWN;
-#ifdef GPK_BUILD_GUDEV
+#ifdef HAVE_GUDEV
 
 	/* get all subsystems */
 	client = g_udev_client_new (NULL);
@@ -138,7 +136,7 @@ gpk_firmware_request_new (const gchar *filename, const gchar *sysfs_path)
 	} else if (g_strcmp0 (subsystem, "pci") == 0) {
 		req->subsystem = GPK_FIRMWARE_SUBSYSTEM_PCI;
 	} else {
-		egg_warning ("subsystem unrecognised: %s", subsystem);
+		g_warning ("subsystem unrecognised: %s", subsystem);
 	}
 
 	/* get model, so we can show something sensible */
@@ -173,7 +171,6 @@ gpk_firmware_request_free (GpkFirmwareRequest *req)
 	g_free (req);
 }
 
-
 /**
  * gpk_firmware_rebind:
  **/
@@ -208,14 +205,14 @@ gpk_firmware_rebind (GpkFirmware *firmware)
 	command = g_strdup_printf ("pkexec %s %s", GPK_FIRMWARE_DEVICE_REBIND_PROGRAM, string->str);
 	ret = g_spawn_command_line_sync (command, &rebind_stdout, &rebind_stderr, &exit_status, &error);
 	if (!ret) {
-		egg_warning ("failed to spawn '%s': %s", command, error->message);
+		g_warning ("failed to spawn '%s': %s", command, error->message);
 		g_error_free (error);
 		goto out;
 	}
 
 	/* if we failed to rebind the device */
 	if (exit_status != 0) {
-		egg_warning ("failed to rebind: %s, %s", rebind_stdout, rebind_stderr);
+		g_warning ("failed to rebind: %s, %s", rebind_stdout, rebind_stderr);
 		ret = FALSE;
 		goto out;
 	}
@@ -244,11 +241,11 @@ gpk_firmware_libnotify_cb (NotifyNotification *notification, gchar *action, gpoi
 	} else if (g_strcmp0 (action, "restart-now") == 0) {
 		ret = egg_console_kit_restart (firmware->priv->consolekit, &error);
 		if (!ret) {
-			egg_warning ("failed to reset: %s", error->message);
+			g_warning ("failed to reset: %s", error->message);
 			g_error_free (error);
 		}
 	} else {
-		egg_warning ("unknown action id: %s", action);
+		g_warning ("unknown action id: %s", action);
 	}
 }
 
@@ -268,7 +265,7 @@ gpk_firmware_require_restart (GpkFirmware *firmware)
 	message = _("You will need to restart this computer before the hardware will work correctly.");
 
 	/* TRANSLATORS: title of libnotify bubble */
-	notification = notify_notification_new (_("Additional software was installed"), message, "help-browser", NULL);
+	notification = notify_notification_new (_("Additional software was installed"), message, NULL);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 
@@ -283,7 +280,7 @@ gpk_firmware_require_restart (GpkFirmware *firmware)
 	/* show the bubble */
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
-		egg_warning ("error: %s", error->message);
+		g_warning ("error: %s", error->message);
 		g_error_free (error);
 	}
 }
@@ -303,14 +300,14 @@ gpk_firmware_require_replug (GpkFirmware *firmware)
 	message = _("You will need to remove and then reinsert the hardware before it will work correctly.");
 
 	/* TRANSLATORS: title of libnotify bubble */
-	notification = notify_notification_new (_("Additional software was installed"), message, "help-browser", NULL);
+	notification = notify_notification_new (_("Additional software was installed"), message, NULL);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 
 	/* show the bubble */
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
-		egg_warning ("error: %s", error->message);
+		g_warning ("error: %s", error->message);
 		g_error_free (error);
 	}
 }
@@ -330,14 +327,14 @@ gpk_firmware_require_nothing (GpkFirmware *firmware)
 	message = _("Your hardware has been set up and is now ready to use.");
 
 	/* TRANSLATORS: title of libnotify bubble */
-	notification = notify_notification_new (_("Additional software was installed"), message, "help-browser", NULL);
+	notification = notify_notification_new (_("Additional software was installed"), message, NULL);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 
 	/* show the bubble */
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
-		egg_warning ("error: %s", error->message);
+		g_warning ("error: %s", error->message);
 		g_error_free (error);
 	}
 }
@@ -361,7 +358,7 @@ gpk_firmware_install_packages_cb (GObject *object, GAsyncResult *res, GpkFirmwar
 	/* get the results */
 	results = pk_client_generic_finish (client, res, &error);
 	if (results == NULL) {
-		egg_warning ("failed to install file: %s", error->message);
+		g_warning ("failed to install file: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -369,7 +366,7 @@ gpk_firmware_install_packages_cb (GObject *object, GAsyncResult *res, GpkFirmwar
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		egg_warning ("failed to install file: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to install file: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 
 		/* ignore some errors */
 		if (pk_error_get_code (error_code) != PK_ERROR_ENUM_PROCESS_KILL &&
@@ -440,21 +437,14 @@ gpk_firmware_install_file (GpkFirmware *firmware)
 static void
 gpk_firmware_ignore_devices (GpkFirmware *firmware)
 {
-	gboolean ret;
 	gchar *existing = NULL;
-	GError *error = NULL;
 	GpkFirmwareRequest *req;
 	GPtrArray *array;
 	GString *string = NULL;
 	guint i;
 
-	/* get from gconf */
-	existing = gconf_client_get_string (firmware->priv->gconf_client, GPK_CONF_IGNORED_DEVICES, &error);
-	if (error != NULL) {
-		egg_warning ("failed to get ignored devices: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
+	/* get from settings */
+	existing = g_settings_get_string (firmware->priv->settings, GPK_SETTINGS_IGNORED_DEVICES);
 
 	/* get existing string */
 	string = g_string_new (existing);
@@ -472,14 +462,9 @@ gpk_firmware_ignore_devices (GpkFirmware *firmware)
 	if (string->len > 2)
 		g_string_set_size (string, string->len - 1);
 
-	/* set new string to gconf */
-	ret = gconf_client_set_string (firmware->priv->gconf_client, GPK_CONF_IGNORED_DEVICES, string->str, &error);
-	if (!ret) {
-		egg_warning ("failed to set new string %s: %s", string->str, error->message);
-		g_error_free (error);
-		goto out;
-	}
-out:
+	/* set new string */
+	g_settings_set_string (firmware->priv->settings, GPK_SETTINGS_IGNORED_DEVICES, string->str);
+
 	g_free (existing);
 	if (string != NULL)
 		g_string_free (string, TRUE);
@@ -507,7 +492,7 @@ gpk_firmware_check_available (GpkFirmware *firmware, const gchar *filename)
 	values = g_strsplit (filename, "&", -1);
 	results = pk_client_search_files (PK_CLIENT(firmware->priv->task), filter, values, NULL, NULL, NULL, &error);
 	if (results == NULL) {
-		egg_warning ("failed to search file %s: %s", filename, error->message);
+		g_warning ("failed to search file %s: %s", filename, error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -515,16 +500,16 @@ gpk_firmware_check_available (GpkFirmware *firmware, const gchar *filename)
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		egg_warning ("failed to search file: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to search file: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
 
 	/* make sure we have one package */
 	array = pk_results_get_package_array (results);
 	if (array->len == 0)
-		egg_debug ("no package providing %s found", filename);
+		g_debug ("no package providing %s found", filename);
 	else if (array->len != 1)
-		egg_warning ("not one package providing %s found (%i)", filename, length);
+		g_warning ("not one package providing %s found (%i)", filename, length);
 	else
 		item = g_object_ref (g_ptr_array_index (array, 0));
 out:
@@ -593,7 +578,7 @@ gpk_firmware_timeout_cb (gpointer data)
 
 	/* nothing to do */
 	if (firmware->priv->packages_found->len == 0) {
-		egg_debug ("no packages providing any of the missing firmware");
+		g_debug ("no packages providing any of the missing firmware");
 		goto out;
 	}
 
@@ -624,7 +609,7 @@ gpk_firmware_timeout_cb (gpointer data)
 	}
 
 	/* TRANSLATORS: title of libnotify bubble */
-	notification = notify_notification_new (_("Additional firmware required"), string->str, "help-browser", NULL);
+	notification = notify_notification_new (_("Additional firmware required"), string->str, NULL);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	notify_notification_add_action (notification, "install-firmware",
@@ -635,7 +620,7 @@ gpk_firmware_timeout_cb (gpointer data)
 					_("Ignore devices"), gpk_firmware_libnotify_cb, firmware, NULL);
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
-		egg_warning ("error: %s", error->message);
+		g_warning ("error: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -657,16 +642,16 @@ gpk_firmware_remove_banned (GpkFirmware *firmware, GPtrArray *array)
 	GpkFirmwareRequest *req;
 	guint i, j;
 
-	/* get from gconf */
-	banned_str = gconf_client_get_string (firmware->priv->gconf_client, GPK_CONF_BANNED_FIRMWARE, NULL);
+	/* get from settings */
+	banned_str = g_settings_get_string (firmware->priv->settings, GPK_SETTINGS_BANNED_FIRMWARE);
 	if (banned_str == NULL) {
-		egg_warning ("could not read banned list");
+		g_warning ("could not read banned list");
 		goto out;
 	}
 
 	/* nothing in list, common case */
 	if (egg_strzero (banned_str)) {
-		egg_debug ("nothing in banned list");
+		g_debug ("nothing in banned list");
 		goto out;
 	}
 
@@ -679,7 +664,7 @@ gpk_firmware_remove_banned (GpkFirmware *firmware, GPtrArray *array)
 		for (j=0; banned[j] != NULL; j++) {
 			ret = g_pattern_match_simple (banned[j], req->filename);
 			if (ret) {
-				egg_debug ("match %s for %s, removing", banned[j], req->filename);
+				g_debug ("match %s for %s, removing", banned[j], req->filename);
 				gpk_firmware_request_free (req);
 				g_ptr_array_remove_index_fast (array, i);
 				break;
@@ -703,16 +688,16 @@ gpk_firmware_remove_ignored (GpkFirmware *firmware, GPtrArray *array)
 	GpkFirmwareRequest *req;
 	guint i, j;
 
-	/* get from gconf */
-	ignored_str = gconf_client_get_string (firmware->priv->gconf_client, GPK_CONF_IGNORED_DEVICES, NULL);
+	/* get from settings */
+	ignored_str = g_settings_get_string (firmware->priv->settings, GPK_SETTINGS_IGNORED_DEVICES);
 	if (ignored_str == NULL) {
-		egg_warning ("could not read ignored list");
+		g_warning ("could not read ignored list");
 		goto out;
 	}
 
 	/* nothing in list, common case */
 	if (egg_strzero (ignored_str)) {
-		egg_debug ("nothing in ignored list");
+		g_debug ("nothing in ignored list");
 		goto out;
 	}
 
@@ -725,7 +710,7 @@ gpk_firmware_remove_ignored (GpkFirmware *firmware, GPtrArray *array)
 		for (j=0; ignored[j] != NULL; j++) {
 			ret = g_pattern_match_simple (ignored[j], req->id);
 			if (ret) {
-				egg_debug ("match %s for %s, removing", ignored[j], req->id);
+				g_debug ("match %s for %s, removing", ignored[j], req->id);
 				gpk_firmware_request_free (req);
 				g_ptr_array_remove_index_fast (array, i);
 				break;
@@ -784,7 +769,7 @@ gpk_firmware_get_device (GpkFirmware *firmware, const gchar *filename)
 	file = g_file_new_for_path (filename);
 	info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET, G_FILE_QUERY_INFO_NONE, NULL, &error);
 	if (info == NULL) {
-		egg_warning ("Failed to get symlink: %s", error->message);
+		g_warning ("Failed to get symlink: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -792,7 +777,7 @@ gpk_firmware_get_device (GpkFirmware *firmware, const gchar *filename)
 	/* /devices/pci0000:00/0000:00:1d.0/usb5/5-2/firmware/5-2 */
 	symlink_path = g_file_info_get_symlink_target (info);
 	if (symlink_path == NULL) {
-		egg_warning ("failed to get symlink target");
+		g_warning ("failed to get symlink target");
 		goto out;
 	}
 
@@ -807,7 +792,7 @@ gpk_firmware_get_device (GpkFirmware *firmware, const gchar *filename)
 	for (i=len; i>1; i--) {
 		split[i] = NULL;
 		target = g_strjoinv ("/", split);
-		egg_debug ("testing %s", target);
+		g_debug ("testing %s", target);
 		if (g_file_test (target, G_FILE_TEST_EXISTS))
 			goto out;
 		g_free (target);
@@ -848,7 +833,7 @@ gpk_firmware_add_file (GpkFirmware *firmware, const gchar *filename_no_path)
 
 	/* this is the file that udev created for us */
 	missing_path = g_build_filename (GPK_FIRMWARE_MISSING_DIR, filename_no_path, NULL);
-	egg_debug ("filename=%s -> %s", missing_path, filename_path);
+	g_debug ("filename=%s -> %s", missing_path, filename_path);
 
 	/* get symlink target */
 	sysfs_path = gpk_firmware_get_device (firmware, missing_path);
@@ -860,11 +845,11 @@ gpk_firmware_add_file (GpkFirmware *firmware, const gchar *filename_no_path)
 	for (i=0; i<array->len; i++) {
 		req = g_ptr_array_index (array, i);
 		if (g_strcmp0 (sysfs_path, req->sysfs_path) == 0) {
-			egg_debug ("ignoring previous sysfs request for %s", sysfs_path);
+			g_debug ("ignoring previous sysfs request for %s", sysfs_path);
 			goto out;
 		}
 		if (g_strcmp0 (filename_path, req->filename) == 0) {
-			egg_debug ("ignoring previous filename request for %s", filename_path);
+			g_debug ("ignoring previous filename request for %s", filename_path);
 			goto out;
 		}
 	}
@@ -892,18 +877,19 @@ gpk_firmware_scan_directory (GpkFirmware *firmware)
 	guint i;
 	GPtrArray *array;
 	const GpkFirmwareRequest *req;
+	guint scan_id = 0;
 
 	/* should we check and show the user */
-	ret = gconf_client_get_bool (firmware->priv->gconf_client, GPK_CONF_ENABLE_CHECK_FIRMWARE, NULL);
+	ret = g_settings_get_boolean (firmware->priv->settings, GPK_SETTINGS_ENABLE_CHECK_FIRMWARE);
 	if (!ret) {
-		egg_debug ("not showing thanks to GConf");
+		g_debug ("not showing thanks to GSettings");
 		return;
 	}
 
 	/* open the directory of requests */
 	dir = g_dir_open (GPK_FIRMWARE_MISSING_DIR, 0, &error);
 	if (dir == NULL) {
-		egg_warning ("failed to open directory: %s", error->message);
+		g_warning ("failed to open directory: %s", error->message);
 		g_error_free (error);
 		return;
 	}
@@ -925,7 +911,7 @@ gpk_firmware_scan_directory (GpkFirmware *firmware)
 	array = firmware->priv->array_requested;
 	for (i=0; i<array->len; i++) {
 		req = g_ptr_array_index (array, i);
-		egg_debug ("requested: %s", req->filename);
+		g_debug ("requested: %s", req->filename);
 	}
 
 	/* remove banned files */
@@ -938,12 +924,14 @@ gpk_firmware_scan_directory (GpkFirmware *firmware)
 	array = firmware->priv->array_requested;
 	for (i=0; i<array->len; i++) {
 		req = g_ptr_array_index (array, i);
-		egg_debug ("searching for: %s", req->filename);
+		g_debug ("searching for: %s", req->filename);
 	}
 
 	/* don't spam the user at startup, so wait a little delay */
-	if (array->len > 0)
-		g_timeout_add_seconds (GPK_FIRMWARE_PROCESS_DELAY, gpk_firmware_timeout_cb, firmware);
+	if (array->len > 0) {
+		scan_id = g_timeout_add_seconds (GPK_FIRMWARE_PROCESS_DELAY, gpk_firmware_timeout_cb, firmware);
+		g_source_set_name_by_id (scan_id, "[GpkFirmware] process");
+	}
 }
 
 /**
@@ -965,13 +953,14 @@ gpk_firmware_monitor_changed_cb (GFileMonitor *monitor, GFile *file, GFile *othe
 				 GFileMonitorEvent event_type, GpkFirmware *firmware)
 {
 	if (firmware->priv->timeout_id > 0) {
-		egg_debug ("clearing timeout as device changed");
+		g_debug ("clearing timeout as device changed");
 		g_source_remove (firmware->priv->timeout_id);
 	}
 
 	/* wait for the device to settle */
 	firmware->priv->timeout_id =
 		g_timeout_add_seconds (GPK_FIRMWARE_INSERT_DELAY, (GSourceFunc) gpk_firmware_scan_directory_cb, firmware);
+	g_source_set_name_by_id (firmware->priv->timeout_id, "[GpkFirmware] changed");
 }
 
 /**
@@ -1000,7 +989,7 @@ gpk_firmware_init (GpkFirmware *firmware)
 	firmware->priv->timeout_id = 0;
 	firmware->priv->packages_found = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	firmware->priv->array_requested = g_ptr_array_new_with_free_func ((GDestroyNotify) gpk_firmware_request_free);
-	firmware->priv->gconf_client = gconf_client_get_default ();
+	firmware->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
 	firmware->priv->consolekit = egg_console_kit_new ();
 	firmware->priv->task = PK_TASK(gpk_task_new ());
 	g_object_set (firmware->priv->task,
@@ -1011,7 +1000,7 @@ gpk_firmware_init (GpkFirmware *firmware)
 	file = g_file_new_for_path (GPK_FIRMWARE_MISSING_DIR);
 	firmware->priv->monitor = g_file_monitor (file, G_FILE_MONITOR_NONE, NULL, &error);
 	if (firmware->priv->monitor == NULL) {
-		egg_warning ("failed to setup monitor: %s", error->message);
+		g_warning ("failed to setup monitor: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -1026,6 +1015,7 @@ out:
 	g_object_unref (file);
 	firmware->priv->timeout_id =
 		g_timeout_add_seconds (GPK_FIRMWARE_LOGIN_DELAY, (GSourceFunc) gpk_firmware_scan_directory_cb, firmware);
+	g_source_set_name_by_id (firmware->priv->timeout_id, "[GpkFirmware] login coldplug");
 }
 
 /**
@@ -1045,7 +1035,7 @@ gpk_firmware_finalize (GObject *object)
 	g_ptr_array_unref (firmware->priv->array_requested);
 	g_ptr_array_unref (firmware->priv->packages_found);
 	g_object_unref (PK_CLIENT(firmware->priv->task));
-	g_object_unref (firmware->priv->gconf_client);
+	g_object_unref (firmware->priv->settings);
 	g_object_unref (firmware->priv->consolekit);
 	if (firmware->priv->monitor != NULL)
 		g_object_unref (firmware->priv->monitor);
