@@ -29,14 +29,11 @@
 #include <sys/types.h>
 #include <pwd.h>
 
-#include <gconf/gconf-client.h>
 #include <packagekit-glib2/packagekit.h>
-#include <unique/unique.h>
-
-#include "egg-debug.h"
 
 #include "gpk-common.h"
 #include "gpk-gnome.h"
+#include "gpk-debug.h"
 
 static GtkBuilder *builder = NULL;
 static GtkListStore *list_store = NULL;
@@ -45,6 +42,7 @@ static gchar *transaction_id = NULL;
 static gchar *filter = NULL;
 static GPtrArray *transactions = NULL;
 static GtkTreePath *path_global = NULL;
+static guint xid = 0;
 
 enum
 {
@@ -170,7 +168,8 @@ gpk_log_get_localised_date (const gchar *timespec)
 	g_date_set_time_val (date, &timeval);
 
 	/* TRANSLATORS: strftime formatted please */
-	g_date_strftime (buffer, 100, _("%A, %d %B %Y"), date);
+	g_date_strftime (buffer, 100, _("%d %B %Y"), date);
+
 	g_date_free (date);
 	return g_strdup (buffer);
 }
@@ -356,23 +355,10 @@ gpk_log_treeview_clicked_cb (GtkTreeSelection *selection, gpointer data)
 		gtk_tree_model_get (model, &iter, GPK_LOG_COLUMN_ID, &id, -1);
 
 		/* show transaction_id */
-		egg_debug ("selected row is: %s", id);
+		g_debug ("selected row is: %s", id);
 		g_free (id);
 	} else {
-		egg_debug ("no row selected");
-	}
-}
-
-/**
- * gpk_log_message_received_cb
- **/
-static void
-gpk_log_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
-{
-	GtkWindow *window;
-	if (command == UNIQUE_ACTIVATE) {
-		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_simple"));
-		gtk_window_present (window);
+		g_debug ("no row selected");
 	}
 }
 
@@ -403,7 +389,7 @@ gpk_log_filter (PkTransactionPast *item)
 
 	/* only show transactions that succeeded */
 	if (!succeeded) {
-		egg_debug ("tid %s did not succeed, so not adding", tid);
+		g_debug ("tid %s did not succeed, so not adding", tid);
 		return FALSE;
 	}
 
@@ -458,7 +444,6 @@ gpk_log_add_item (PkTransactionPast *item)
 	GtkTreeIter iter;
 	gchar *details;
 	gchar *date;
-	gchar **date_part;
 	const gchar *icon_name;
 	const gchar *role_text;
 	const gchar *username = NULL;
@@ -491,7 +476,6 @@ gpk_log_add_item (PkTransactionPast *item)
 	/* put formatted text into treeview */
 	details = gpk_log_get_details_localised (timespec, data);
 	date = gpk_log_get_localised_date (timespec);
-	date_part = g_strsplit (date, ", ", 2);
 
 	icon_name = gpk_role_enum_to_icon_name (role);
 	role_text = gpk_role_enum_to_localised_past (role);
@@ -525,7 +509,7 @@ gpk_log_add_item (PkTransactionPast *item)
 	gtk_list_store_set (list_store, &iter,
 			    GPK_LOG_COLUMN_ICON, icon_name,
 			    GPK_LOG_COLUMN_TIMESPEC, timespec,
-			    GPK_LOG_COLUMN_DATE_TEXT, date_part[1],
+			    GPK_LOG_COLUMN_DATE_TEXT, date,
 			    GPK_LOG_COLUMN_DATE, timespec,
 			    GPK_LOG_COLUMN_ROLE, role_text,
 			    GPK_LOG_COLUMN_DETAILS, details,
@@ -539,7 +523,6 @@ gpk_log_add_item (PkTransactionPast *item)
 		while (gtk_events_pending ())
 			gtk_main_iteration ();
 
-	g_strfreev (date_part);
 	g_free (tid);
 	g_free (timespec);
 	g_free (cmdline);
@@ -571,7 +554,7 @@ gpk_log_refilter (void)
 	else
 		filter = NULL;
 
-	egg_debug ("len=%i", transactions->len);
+	g_debug ("len=%i", transactions->len);
 
 	/* mark the items as not used */
 	treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_simple"));
@@ -604,7 +587,7 @@ gpk_log_get_old_transactions_cb (GObject *object, GAsyncResult *res, gpointer us
 	/* get the results */
 	results = pk_client_generic_finish (client, res, &error);
 	if (results == NULL) {
-		egg_warning ("failed to get old transactions: %s", error->message);
+		g_warning ("failed to get old transactions: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -612,7 +595,7 @@ gpk_log_get_old_transactions_cb (GObject *object, GAsyncResult *res, gpointer us
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		egg_warning ("failed to get old transactions: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to get old transactions: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
 
@@ -669,69 +652,49 @@ gpk_log_entry_filter_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_da
 }
 
 /**
- * main:
+ * gpk_log_delete_event_cb:
  **/
-int
-main (int argc, char *argv[])
+static gboolean
+gpk_log_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
+{
+	g_application_release (G_APPLICATION (application));
+	return FALSE;
+}
+
+/**
+ * gpk_log_button_close_cb:
+ **/
+static void
+gpk_log_button_close_cb (GtkWidget *widget, GtkApplication *application)
+{
+	g_application_release (G_APPLICATION (application));
+}
+
+/**
+ * gpk_log_activate_cb:
+ **/
+static void
+gpk_log_activate_cb (GtkApplication *application, gpointer user_data)
+{
+	GtkWindow *window;
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_simple"));
+	gtk_window_present (window);
+}
+
+/**
+ * gpk_log_startup_cb:
+ **/
+static void
+gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 {
-	GOptionContext *context;
-	GConfClient *gconf_client;
-	GtkWidget *widget;
-	GtkTreeSelection *selection;
-	GtkEntryCompletion *completion;
-	UniqueApp *unique_app;
 	gboolean ret;
-	guint retval;
-	guint xid = 0;
 	GError *error = NULL;
-
-	const GOptionEntry options[] = {
-		{ "filter", 'f', 0, G_OPTION_ARG_STRING, &filter,
-		  /* TRANSLATORS: preset the GtktextBox with this filter text */
-		  N_("Set the filter to this value"), NULL },
-		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
-		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
-		  _("Set the parent window to make this modal"), NULL },
-		{ NULL}
-	};
-
-	setlocale (LC_ALL, "");
-
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
-	g_type_init ();
-	gtk_init (&argc, &argv);
-
-	context = g_option_context_new (NULL);
-	g_option_context_set_summary (context, _("Software Log Viewer"));
-	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
-	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	g_option_context_parse (context, &argc, &argv, NULL);
-	g_option_context_free (context);
-
-	/* are we running privileged */
-	ret = gpk_check_privileged_user (_("Log viewer"), TRUE);
-	if (!ret)
-		return 1;
-
-	/* are we already activated? */
-	unique_app = unique_app_new ("org.freedesktop.PackageKit.LogViewer", NULL);
-	if (unique_app_is_running (unique_app)) {
-		egg_debug ("You have another instance running. This program will now close");
-		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
-		goto unique_out;
-	}
-	g_signal_connect (unique_app, "message-received",
-			  G_CALLBACK (gpk_log_message_received_cb), NULL);
-
-	/* add application specific icons to search path */
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-					   GPK_DATA G_DIR_SEPARATOR_S "icons");
+	GSettings *settings;
+	GtkEntryCompletion *completion;
+	GtkTreeSelection *selection;
+	GtkWidget *widget;
+	GtkWindow *window;
+	guint retval;
 
 	client = pk_client_new ();
 	g_object_set (client,
@@ -742,16 +705,21 @@ main (int argc, char *argv[])
 	builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-log.ui", &error);
 	if (retval == 0) {
-		egg_warning ("failed to load ui: %s", error->message);
+		g_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
-		goto out_build;
+		goto out;
 	}
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_simple"));
-	gtk_window_set_icon_name (GTK_WINDOW (widget), GPK_ICON_SOFTWARE_LOG);
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_simple"));
+	gtk_window_set_icon_name (window, GPK_ICON_SOFTWARE_LOG);
+	gtk_window_set_application (window, application);
 
 	/* set a size, if the screen allows */
-	gpk_window_set_size_request (GTK_WINDOW (widget), 900, 300);
+	gpk_window_set_size_request (window, 900, 300);
+
+	/* Get the main window quit */
+	g_signal_connect (window, "delete-event",
+			  G_CALLBACK (gpk_log_delete_event_cb), application);
 
 	/* if command line arguments are set, then setup UI */
 	if (filter != NULL) {
@@ -759,11 +727,9 @@ main (int argc, char *argv[])
 		gtk_entry_set_text (GTK_ENTRY(widget), filter);
 	}
 
-	/* Get the main window quit */
-	g_signal_connect_swapped (widget, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
-
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "clicked",
+			  G_CALLBACK (gpk_log_button_close_cb), application);
 	gtk_widget_grab_default (widget);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -779,8 +745,8 @@ main (int argc, char *argv[])
 	g_signal_connect (widget, "activate", G_CALLBACK (gpk_log_button_filter_cb), NULL);
 
 	/* autocompletion can be turned off as it's slow */
-	gconf_client = gconf_client_get_default ();
-	ret = gconf_client_get_bool (gconf_client, GPK_CONF_AUTOCOMPLETE, NULL);
+	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
+	ret = g_settings_get_boolean (settings, GPK_SETTINGS_AUTOCOMPLETE);
 	if (ret) {
 		/* create the completion object */
 		completion = gpk_package_entry_completion_new ();
@@ -791,7 +757,7 @@ main (int argc, char *argv[])
 		/* use search as you type */
 		g_signal_connect (widget, "key-release-event", G_CALLBACK (gpk_log_entry_filter_cb), NULL);
 	}
-	g_object_unref (gconf_client);
+	g_object_unref (settings);
 
 	/* create list stores */
 	list_store = gtk_list_store_new (GPK_LOG_COLUMN_LAST, G_TYPE_STRING, G_TYPE_STRING,
@@ -820,24 +786,82 @@ main (int argc, char *argv[])
 
 	/* set the parent window if it is specified */
 	if (xid != 0) {
-		egg_debug ("Setting xid %i", xid);
+		g_debug ("Setting xid %i", xid);
 		gpk_window_set_parent_xid (GTK_WINDOW (widget), xid);
 	}
 
 	/* get the update list */
 	gpk_log_refresh ();
-
-	gtk_main ();
-
-out_build:
-	g_object_unref (builder);
+out:
 	g_object_unref (list_store);
 	g_object_unref (client);
 	g_free (transaction_id);
 	g_free (filter);
 	if (transactions != NULL)
 		g_ptr_array_unref (transactions);
-unique_out:
-	g_object_unref (unique_app);
-	return 0;
+}
+
+/**
+ * main:
+ **/
+int
+main (int argc, char *argv[])
+{
+	gboolean ret;
+	gint status = 1;
+	GOptionContext *context;
+	GtkApplication *application;
+
+	const GOptionEntry options[] = {
+		{ "filter", 'f', 0, G_OPTION_ARG_STRING, &filter,
+		  /* TRANSLATORS: preset the GtktextBox with this filter text */
+		  N_("Set the filter to this value"), NULL },
+		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
+		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
+		  _("Set the parent window to make this modal"), NULL },
+		{ NULL}
+	};
+
+	setlocale (LC_ALL, "");
+
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	if (! g_thread_supported ())
+		g_thread_init (NULL);
+	g_type_init ();
+	gtk_init (&argc, &argv);
+
+	context = g_option_context_new (NULL);
+	g_option_context_set_summary (context, _("Software Log Viewer"));
+	g_option_context_add_main_entries (context, options, NULL);
+	g_option_context_add_group (context, gpk_debug_get_option_group ());
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
+	g_option_context_parse (context, &argc, &argv, NULL);
+	g_option_context_free (context);
+
+	/* are we running privileged */
+	ret = gpk_check_privileged_user (_("Log viewer"), TRUE);
+	if (!ret)
+		goto out;
+
+	/* add application specific icons to search path */
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+					   GPK_DATA G_DIR_SEPARATOR_S "icons");
+
+	/* are we already activated? */
+	application = gtk_application_new ("org.freedesktop.PackageKit.LogViewer", 0);
+	g_signal_connect (application, "startup",
+			  G_CALLBACK (gpk_log_startup_cb), NULL);
+	g_signal_connect (application, "activate",
+			  G_CALLBACK (gpk_log_activate_cb), NULL);
+
+	/* run */
+	status = g_application_run (G_APPLICATION (application), argc, argv);
+out:
+	if (builder != NULL)
+		g_object_unref (builder);
+	g_object_unref (application);
+	return status;
 }
