@@ -27,9 +27,7 @@
 #include <gtk/gtk.h>
 #include <sys/utsname.h>
 #include <packagekit-glib2/packagekit.h>
-#include <unique/unique.h>
 
-#include "egg-debug.h"
 #include "egg-string.h"
 
 #include "gpk-common.h"
@@ -81,6 +79,10 @@ gpk_pack_get_default_filename (const gchar *directory)
 	g_object_get (control,
 		      "distro-id", &distro_id,
 		      NULL);
+
+	/* make a sane filename */
+	g_strdelimit (distro_id, ";", '-');
+
 	if (action == GPK_ACTION_ENUM_PACKAGE) {
 		entry = GTK_ENTRY (gtk_builder_get_object (builder, "entry_package"));
 		package = gtk_entry_get_text (entry);
@@ -158,9 +160,7 @@ gpk_pack_set_percentage (guint percentage)
 		/* set pulsing */
 		if (pulse_id == 0) {
 			pulse_id = g_timeout_add (100, gpk_pack_percentage_pulse_cb, NULL);
-#if GLIB_CHECK_VERSION(2,25,8)
 			g_source_set_name_by_id (pulse_id, "[GpkServicePack] pulse");
-#endif
 		}
 		return;
 	}
@@ -193,7 +193,7 @@ gpk_pack_resolve_package_id (const gchar *package)
 	packages = g_strsplit (package, ";", 0);
 	results = pk_client_resolve (client, pk_bitfield_value (PK_FILTER_ENUM_NEWEST), packages, NULL, NULL, NULL, &error);
 	if (results == NULL) {
-		egg_warning ("failed to resolve: %s", error->message);
+		g_warning ("failed to resolve: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -201,7 +201,7 @@ gpk_pack_resolve_package_id (const gchar *package)
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		egg_warning ("failed to resolve: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to resolve: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
 
@@ -214,7 +214,7 @@ gpk_pack_resolve_package_id (const gchar *package)
 
 	/* display warning if not exactly one match */
 	if (array->len > 1)
-		egg_warning ("More than one possible package for '%s' found!", package);
+		g_warning ("More than one possible package for '%s' found!", package);
 
 	/* convert to a text package id */
 	item = g_ptr_array_index (array, 0);
@@ -341,7 +341,7 @@ gpk_pack_copy_package_lists (const gchar *filename, GError **error)
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		egg_warning ("failed to get packages: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		g_warning ("failed to get packages: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
 
@@ -350,7 +350,7 @@ gpk_pack_copy_package_lists (const gchar *filename, GError **error)
 
 	/* convert to a file */
 	data = gpk_pack_package_array_to_string (array);
-	ret = g_file_set_contents (PK_SYSTEM_PACKAGE_LIST_FILENAME, data, -1, &error_local);
+	ret = g_file_set_contents (filename, data, -1, &error_local);
 	if (!ret) {
 		g_set_error (error, 1, 0, _("Could not save to file: %s"), error_local->message);
 		g_error_free (error_local);
@@ -367,6 +367,25 @@ out:
 	return ret;
 }
 
+/**
+ * gpk_pack_reset_ui:
+ **/
+static void
+gpk_pack_reset_ui (void)
+{
+	GtkWidget *widget;
+
+	/* stop the action */
+	gpk_pack_widgets_activate (TRUE);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
+	gtk_widget_hide (widget);
+	gpk_pack_set_percentage (100);
+
+	/* blank */
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progressbar_percentage"));
+	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), "");
+}
+
 /**
  * gpk_pack_ready_cb:
  **/
@@ -387,18 +406,10 @@ gpk_pack_ready_cb (GObject *object, GAsyncResult *res, gpointer userdata)
 		g_error_free (error);
 	}
 
-	/* stop the action */
-	gpk_pack_widgets_activate (TRUE);
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
-	gtk_widget_hide (widget);
-	gpk_pack_set_percentage (100);
-
-	/* blank */
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progressbar_percentage"));
-	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), "");
+	/* reset regardless of success/failure */
+	gpk_pack_reset_ui ();
 }
 
-
 /**
  * gpk_pack_progress_cb:
  **/
@@ -419,7 +430,7 @@ gpk_pack_progress_cb (PkProgress *progress, PkProgressType type, gpointer userda
 		      NULL);
 
 	if (type == PK_PROGRESS_TYPE_STATUS) {
-		egg_debug ("now %s", pk_status_enum_to_text (status));
+		g_debug ("now %s", pk_status_enum_to_text (status));
 	} else if (type == PK_PROGRESS_TYPE_PERCENTAGE) {
 		gpk_pack_set_percentage (percentage);
 	} else if (type == PK_PROGRESS_TYPE_PACKAGE_ID) {
@@ -518,6 +529,7 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot copy system package array"), error->message);
 			g_error_free (error);
 		}
+		gpk_pack_reset_ui ();
 		goto out;
 	}
 
@@ -573,7 +585,7 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 		/* check error code */
 		error_code = pk_results_get_error_code (results);
 		if (error_code != NULL) {
-			egg_warning ("failed to refresh cache: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+			g_warning ("failed to refresh cache: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 			goto out;
 		}
 
@@ -615,19 +627,6 @@ out:
 	g_free (exclude);
 }
 
-/**
- * gpk_pack_message_received_cb
- **/
-static void
-gpk_pack_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
-{
-	GtkWindow *window;
-	if (command == UNIQUE_ACTIVATE) {
-		window = GTK_WINDOW (gtk_builder_get_object (builder, "window_prefs"));
-		gtk_window_present (window);
-	}
-}
-
 /**
  * gpk_pack_radio_updates_cb:
  **/
@@ -635,7 +634,7 @@ static void
 gpk_pack_radio_updates_cb (GtkWidget *widget2, gpointer data)
 {
 	GtkWidget *widget;
-	egg_debug ("got updates");
+	g_debug ("got updates");
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "entry_package"));
 	gtk_widget_set_sensitive (widget, FALSE);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
@@ -650,7 +649,7 @@ static void
 gpk_pack_radio_package_cb (GtkWidget *widget2, gpointer data)
 {
 	GtkWidget *widget;
-	egg_debug ("got package");
+	g_debug ("got package");
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "entry_package"));
 	gtk_widget_set_sensitive (widget, TRUE);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
@@ -665,7 +664,7 @@ static void
 gpk_pack_radio_copy_cb (GtkWidget *widget2, gpointer data)
 {
 	GtkWidget *widget;
-	egg_debug ("got copy");
+	g_debug ("got copy");
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "entry_package"));
 	gtk_widget_set_sensitive (widget, FALSE);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
@@ -674,77 +673,39 @@ gpk_pack_radio_copy_cb (GtkWidget *widget2, gpointer data)
 }
 
 /**
- * main:
+ * gpk_pack_delete_event_cb:
  **/
-int
-main (int argc, char *argv[])
+static gboolean
+gpk_pack_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
+{
+	g_application_release (G_APPLICATION (application));
+	return FALSE;
+}
+
+/**
+ * gpk_pack_button_close_cb:
+ **/
+static void
+gpk_pack_button_close_cb (GtkWidget *widget, GtkApplication *application)
+{
+	g_application_release (G_APPLICATION (application));
+}
+
+/**
+ * gpk_pack_startup_cb:
+ **/
+static void
+gpk_pack_startup_cb (GtkApplication *application, gpointer user_data)
 {
-	GOptionContext *context;
 	GtkWidget *main_window;
 	GtkWidget *widget;
 	GtkFileFilter *filter;
 	GtkEntryCompletion *completion;
-	UniqueApp *unique_app;
 	gboolean ret;
-	GSettings *settings = NULL;
-	gchar *option = NULL;
-	gchar *package = NULL;
-	gchar *with_array = NULL;
-	gchar *output = NULL;
 	guint retval;
+	GSettings *settings = NULL;
 	GError *error = NULL;
 
-	const GOptionEntry options[] = {
-		{ "option", 'o', 0, G_OPTION_ARG_STRING, &option,
-		  /* TRANSLATORS: the constants should not be translated */
-		  _("Set the option, allowable values are 'array', 'updates' and 'package'"), NULL },
-		{ "package", 'p', 0, G_OPTION_ARG_STRING, &package,
-		  /* TRANSLATORS: this refers to the GtkTextEntry in gpk-service-pack */
-		  _("Add the package name to the text entry box"), NULL },
-		{ "with-array", 'p', 0, G_OPTION_ARG_STRING, &with_array,
-		  /* TRANSLATORS: this is the destination computer package array */
-		  _("Set the remote package array filename"), NULL },
-		{ "output", 'p', 0, G_OPTION_ARG_STRING, &output,
-		  /* TRANSLATORS: this is the file output directory */
-		  _("Set the default output directory"), NULL },
-		{ NULL}
-	};
-
-	setlocale (LC_ALL, "");
-
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
-	g_type_init ();
-
-	context = g_option_context_new (NULL);
-	/* TRANSLATORS: program description, an application to create service packs */
-	g_option_context_set_summary (context, _("Service Pack Creator"));
-	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
-	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	ret = g_option_context_parse (context, &argc, &argv, &error);
-	if (!ret) {
-		g_error ("failed to parse %s", error->message);
-		g_error_free (error);
-	}
-	g_option_context_free (context);
-
-	gtk_init (&argc, &argv);
-
-	/* are we already activated? */
-	unique_app = unique_app_new ("org.freedesktop.PackageKit.ServicePack", NULL);
-	if (unique_app_is_running (unique_app)) {
-		egg_debug ("You have another instance running. This program will now close");
-		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
-		goto out_unique;
-	}
-	g_signal_connect (unique_app, "message-received",
-			  G_CALLBACK (gpk_pack_message_received_cb), NULL);
-
 	/* use a client to download packages */
 	client = pk_client_new ();
 	g_object_set (client,
@@ -755,7 +716,7 @@ main (int argc, char *argv[])
 	control = pk_control_new ();
 	ret = pk_control_get_properties (control, NULL, &error);
 	if (!ret) {
-		egg_error ("Failed to contact PackageKit: %s", error->message);
+		g_error ("Failed to contact PackageKit: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -763,19 +724,21 @@ main (int argc, char *argv[])
 	builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-service-pack.ui", &error);
 	if (retval == 0) {
-		egg_warning ("failed to load ui: %s", error->message);
+		g_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
-		goto out_build;
+		goto out;
 	}
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
+	gtk_application_add_window (application, GTK_WINDOW (main_window));
 
 	/* Hide window first so that the dialogue resizes itself without redrawing */
 	gtk_widget_hide (main_window);
 	gtk_window_set_icon_name (GTK_WINDOW (main_window), GPK_ICON_SERVICE_PACK);
 
 	/* Get the main window quit */
-	g_signal_connect_swapped (main_window, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (main_window, "delete-event",
+			  G_CALLBACK (gpk_pack_delete_event_cb), application);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
 	filter = gtk_file_filter_new ();
@@ -799,7 +762,7 @@ main (int argc, char *argv[])
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_radio_copy_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_button_close_cb), application);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_create"));
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_button_create_cb), NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -819,6 +782,59 @@ main (int argc, char *argv[])
 		g_object_unref (completion);
 	}
 
+	gtk_widget_show (main_window);
+out:
+	if (settings != NULL)
+		g_object_unref (settings);
+}
+
+/**
+ * gpm_pack_commandline_cb:
+ **/
+static int
+gpm_pack_commandline_cb (GApplication *application,
+			 GApplicationCommandLine *cmdline,
+			 gpointer user_data)
+{
+	gboolean ret;
+	gchar **argv;
+	gchar *option = NULL;
+	gchar *package = NULL;
+	gchar *with_array = NULL;
+	gchar *output = NULL;
+	gint argc;
+	GOptionContext *context;
+	GtkWidget *widget;
+	GtkWindow *window;
+
+	const GOptionEntry options[] = {
+		{ "option", 'o', 0, G_OPTION_ARG_STRING, &option,
+		  /* TRANSLATORS: the constants should not be translated */
+		  _("Set the option, allowable values are 'array', 'updates' and 'package'"), NULL },
+		{ "package", 'p', 0, G_OPTION_ARG_STRING, &package,
+		  /* TRANSLATORS: this refers to the GtkTextEntry in gpk-service-pack */
+		  _("Add the package name to the text entry box"), NULL },
+		{ "with-array", 'p', 0, G_OPTION_ARG_STRING, &with_array,
+		  /* TRANSLATORS: this is the destination computer package array */
+		  _("Set the remote package array filename"), NULL },
+		{ "output", 'p', 0, G_OPTION_ARG_STRING, &output,
+		  /* TRANSLATORS: this is the file output directory */
+		  _("Set the default output directory"), NULL },
+		{ NULL}
+	};
+
+	/* get arguments */
+	argv = g_application_command_line_get_arguments (cmdline, &argc);
+
+	context = g_option_context_new (NULL);
+	/* TRANSLATORS: the program name */
+	g_option_context_set_summary (context, _("Service Pack Creator"));
+	g_option_context_add_main_entries (context, options, NULL);
+//	g_option_context_add_group (context, gpk_debug_get_option_group ());
+	ret = g_option_context_parse (context, &argc, &argv, NULL);
+	if (!ret)
+		goto out;
+
 	/* if command line arguments are set, then setup UI */
 	if (option != NULL) {
 		if (g_strcmp0 (option, "array") == 0) {
@@ -845,25 +861,58 @@ main (int argc, char *argv[])
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER(widget), output);
 	}
 
-	gtk_widget_show (main_window);
-
-	/* wait */
-	gtk_main ();
-
-out_build:
-	g_object_unref (builder);
-out_unique:
-	g_object_unref (unique_app);
-	if (settings != NULL)
-		g_object_unref (settings);
-	if (control != NULL)
-		g_object_unref (control);
-	if (client != NULL)
-		g_object_unref (client);
+	/* make sure the window is raised */
+	window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_pack"));
+	gtk_window_present (window);
+out:
 	g_free (option);
 	g_free (package);
 	g_free (with_array);
 	g_free (output);
+	g_strfreev (argv);
+	g_option_context_free (context);
+	return ret;
+}
 
-	return 0;
+/**
+ * main:
+ **/
+int
+main (int argc, char *argv[])
+{
+	GtkApplication *application;
+	gint status = 0;
+
+	setlocale (LC_ALL, "");
+
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	if (! g_thread_supported ())
+		g_thread_init (NULL);
+	g_type_init ();
+
+	gtk_init (&argc, &argv);
+
+	/* are we already activated? */
+	application = gtk_application_new ("org.freedesktop.PackageKit.ServicePack",
+					   G_APPLICATION_HANDLES_COMMAND_LINE);
+	g_signal_connect (application, "startup",
+			  G_CALLBACK (gpk_pack_startup_cb), NULL);
+	g_signal_connect (application, "command-line",
+			  G_CALLBACK (gpm_pack_commandline_cb), NULL);
+
+	/* run */
+	status = g_application_run (G_APPLICATION (application), argc, argv);
+
+	g_object_unref (application);
+	if (builder != NULL)
+		g_object_unref (builder);
+	if (control != NULL)
+		g_object_unref (control);
+	if (client != NULL)
+		g_object_unref (client);
+
+	return status;
 }
